import requests
import requests_cache
import json
import time
from decimal import *


def convert(amount, to_currency, app_id):

    exchange_obj = __fetch_rates(app_id)

    rates = exchange_obj['rates']

    # solve for the result
    try:
        result = (1 / Decimal(rates[to_currency]) * Decimal(amount))
    except KeyError:
        error_msg = 'The exchange rate for '+to_currency+' cannot be found.'
        raise Exception(error_msg)
    return result


def __fetch_rates(app_id):

    requests_cache.install_cache(expire_after=3600)

    # get the json exchange rates to USD
    request_url = 'https://openexchangerates.org/api/latest.json?app_id='+app_id+'&base=USD&prettyprint=false'

    req_ob = requests.get(request_url)

    return req_ob.json()



import pathlib2
import setuptools

# The directory containing this file
HERE = pathlib2.Path(__file__).parent

# The text of the README file
README = (HERE / "README.md").read_text()

setuptools.setup(
    name="pyUSDforex",
    version="0.1.3.1",
    author="Lawrence Stewart",
    author_email="lawrence@lawrencestewart.ca",
    description="Converts foreign fiat currencies to USD by getting and caching hourly exchanges rates from openexchangerates.org",
    long_description=README,
    long_description_content_type="text/markdown",
    url="https://github.com/getorca/pyUSDforex",
    packages=setuptools.find_packages(),
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
)
